@@ -415,8 +415,8 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     if (ac) {
         ac->addAction(QStringLiteral("add_emoticon"), d->action_add_emoticon);
     }
-    connect(d->action_add_emoticon, &EmoticonTextEditAction::emoticonActivated, d->composerControler, &RichTextComposerControler::slotAddEmoticon);
-    d->richTextActionList.append(d->action_add_emoticon);
+    //Don't add to d->richTextActionList as we want to use it when we use plain text email too
+    connect(d->action_add_emoticon, &EmoticonTextEditAction::emoticonActivated, d->composerControler->richTextComposer(), &RichTextComposer::insertEmoticon);
 
     d->action_insert_html = new QAction(i18n("Insert HTML"), this);
     d->action_insert_html->setObjectName(QStringLiteral("insert_html"));
@@ -498,6 +498,7 @@ void RichTextComposerActions::setActionsEnabled(bool enabled)
     for (QAction *action : qAsConst(d->richTextActionList)) {
         action->setEnabled(enabled);
     }
+    d->action_add_emoticon->setEmojiPlainText(!enabled);
     d->richTextEnabled = enabled;
 }
 
@@ -507,7 +508,7 @@ void RichTextComposerActions::slotUpdateCharFormatActions(const QTextCharFormat
 
     d->action_font_family->setFont(f.family());
     if (f.pointSize() > 0) {
-        d->action_font_size->setFontSize((int)f.pointSize());
+        d->action_font_size->setFontSize(f.pointSize());
     }
     d->action_text_bold->setChecked(f.bold());
     d->action_text_italic->setChecked(f.italic());
