@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,7 +22,7 @@
 #include "inserttablewidget.h"
 
 #include <KLocalizedString>
-#include <KComboBox>
+#include <QComboBox>
 #include <KSeparator>
 #include <KColorButton>
 
@@ -46,7 +46,7 @@ public:
 
         QWidget *page = new QWidget(q);
         QVBoxLayout *lay = new QVBoxLayout(page);
-        lay->setMargin(0);
+        lay->setContentsMargins(0, 0, 0, 0);
         tableWidget = new InsertTableWidget;
         lay->addWidget(tableWidget);
 
@@ -76,7 +76,7 @@ public:
         sep = new KSeparator;
         lay->addWidget(sep);
 
-        alignment = new KComboBox;
+        alignment = new QComboBox;
         alignment->addItem(i18n("Left"), Qt::AlignLeft);
         alignment->addItem(i18n("Right"), Qt::AlignRight);
         alignment->addItem(i18n("Center"), Qt::AlignHCenter);
@@ -115,7 +115,7 @@ public:
 
     QCheckBox *useBackgroundColor = nullptr;
     KColorButton *backgroundColor = nullptr;
-    KComboBox *alignment = nullptr;
+    QComboBox *alignment = nullptr;
     QSpinBox *spacing = nullptr;
     QSpinBox *padding = nullptr;
     KPIMTextEdit::InsertTableWidget *tableWidget = nullptr;
